==> jboss-eap-7.1.2-src.zip: jboss-eap-7.1-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/ejb/interceptor/lifecycle/chains/LifecycleInterceptorWithProceed.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.integration.ejb.interceptor.lifecycle.chains;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.interceptor.InvocationContext;

/**
 * @author Stuart Douglas
 */
public class LifecycleInterceptorWithProceed {

    public static boolean postConstruct = false;
    public static boolean postConstructFinished = false;
    public static boolean preDestroy = false;

    @PostConstruct
    private void postConstruct(InvocationContext ctx) throws Exception {
        postConstruct = true;
        ctx.proceed();
        postConstructFinished = true;
    }

    @PreDestroy
    private void preDestroy(InvocationContext ctx) throws Exception {
        preDestroy = true;
        ctx.proceed();
    }


}

==> jboss-eap-8.0.8-src.zip: jboss-eap-8.0-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/ejb/interceptor/lifecycle/chains/LifecycleInterceptorWithProceed.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.integration.ejb.interceptor.lifecycle.chains;

import jakarta.annotation.PostConstruct;
import jakarta.annotation.PreDestroy;
import jakarta.interceptor.InvocationContext;

/**
 * @author Stuart Douglas
 */
public class LifecycleInterceptorWithProceed {

    public static boolean postConstruct = false;
    public static boolean postConstructFinished = false;
    public static boolean preDestroy = false;

    @PostConstruct
    private void postConstruct(InvocationContext ctx) throws Exception {
        postConstruct = true;
        ctx.proceed();
        postConstructFinished = true;
    }

    @PreDestroy
    private void preDestroy(InvocationContext ctx) throws Exception {
        preDestroy = true;
        ctx.proceed();
    }


}
